#ifndef emboss_h
#define emboss_h

#include "ajax.h"
#include "ajgraph.h"
#include "ajgraphstruct.h"
#include "ajhist.h"
#include "ensembl.h"
#include "ajseqdb.h"
#include "ajacd.h"
#include "embaln.h"
#include "embcom.h"
#include "embcons.h"
#include "embdbi.h"
#include "embread.h"
#include "embiep.h"
#include "embprop.h"
#include "embinit.h"
#include "embword.h"
#include "embpat.h"
#include "embpatlist.h"
#include "embmat.h"
#include "embdata.h"
#include "embnmer.h"
#include "embgroup.h"
#include "embshow.h"
#include "embmisc.h"
#include "embmol.h"
#include "embpdb.h"
#include "embdomain.h"
#include "embsig.h"
#include "embdmx.h"
#include "embexit.h"
#include "embindex.h"
#include "embest.h"

#endif
